@@ -1,6 +1,6 @@
 /*--------------------------------------------------------------------
  *
- *    Copyright (c) 2004-2019 by the GMT Team (https://www.generic-mapping-tools.org/team.html) and Michael Chandler
+ *    Copyright (c) 2004-2020 by the GMT Team (https://www.generic-mapping-tools.org/team.html) and Michael Chandler
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -40,43 +40,43 @@ EXTERN_MSC int MGD77_Read_File_nohdr (struct GMT_CTRL *GMT, char *file, struct M
 
 struct MGD77HEADER_CTRL {	/* All control options for this program (except common args) */
 	/* active is true if the option has been activated */
-	struct H {	/* -H<file> */
+	struct MGD77HEADER_H {	/* -H<file> */
 		bool active;
 		char *file;
 	} H;
-	struct M {	/* -Mf[<item>|r|t] */
+	struct MGD77HEADER_M {	/* -Mf[<item>|r|t] */
 		bool active;
 		unsigned int mode;
 		unsigned int flag;
 	} M;
 };
 
-GMT_LOCAL void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
+static void *New_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct MGD77HEADER_CTRL *C = NULL;
-	
+
 	C = gmt_M_memory (GMT, NULL, 1, struct MGD77HEADER_CTRL);
-	
+
 	/* Initialize values whose defaults are not 0/false/NULL */
-	
+
 	C->M.mode = 1;
 	return (C);
 }
 
-GMT_LOCAL void Free_Ctrl (struct GMT_CTRL *GMT, struct MGD77HEADER_CTRL *C) {	/* Deallocate control structure */
+static void Free_Ctrl (struct GMT_CTRL *GMT, struct MGD77HEADER_CTRL *C) {	/* Deallocate control structure */
 	if (!C) return;
 	gmt_M_str_free (C->H.file);
-	gmt_M_free (GMT, C);	
+	gmt_M_free (GMT, C);
 }
 
-GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
+static int usage (struct GMTAPI_CTRL *API, int level) {
 	struct MGD77_CONTROL M;
 
 	const char *name = gmt_show_name_and_purpose (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_PURPOSE);
 	if (level == GMT_MODULE_PURPOSE) return (GMT_NOERROR);
 	GMT_Message (API, GMT_TIME_NONE, "usage: %s <cruise(s)>  [-H<headinfo>] [-Mf[<item>]|r|e|h] [%s] [%s]\n\n", name, GMT_V_OPT, GMT_PAR_OPT);
-        
+
 	if (level == GMT_SYNOPSIS) return (GMT_MODULE_SYNOPSIS);
-             
+
 	MGD77_Init (API->GMT, &M);		/* Initialize MGD77 Machinery */
 	MGD77_Cruise_Explain (API->GMT);
 	GMT_Message (API, GMT_TIME_NONE, "\n\tOPTIONS:\n");
@@ -91,13 +91,13 @@ GMT_LOCAL int usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE, "\t     r: Display raw original MGD77 header records [Default].\n");
 	GMT_Message (API, GMT_TIME_NONE, "\t     t: Display raw original M77T header records.\n");
 	GMT_Option (API, "V,.");
-	
+
 	MGD77_end (API->GMT, &M);	/* Close machinery */
 
 	return (GMT_MODULE_USAGE);
 }
 
-GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct MGD77HEADER_CTRL *Ctrl, struct GMT_OPTION *options, struct MGD77_CONTROL *M) {
+static int parse (struct GMT_CTRL *GMT, struct MGD77HEADER_CTRL *Ctrl, struct GMT_OPTION *options, struct MGD77_CONTROL *M) {
 	/* This parses the options provided to mgd77info and sets parameters in CTRL.
 	 * Any GMT common options will override values set previously by other commands.
 	 * It also replaces any file names specified as input or output with the data ID
@@ -122,7 +122,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct MGD77HEADER_CTRL *Ctrl, struct
 				Ctrl->H.active = true;
 				Ctrl->H.file = strdup (opt->arg);
 				break;
-				
+
 			case 'M':
 				Ctrl->M.active = true;
 				if (opt->arg[0] == 'f') {
@@ -136,7 +136,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct MGD77HEADER_CTRL *Ctrl, struct
 				else if (opt->arg[0] == 't')
 					Ctrl->M.mode = M77T_HEADER;
 				else {
-					GMT_Report (API, GMT_MSG_NORMAL, "Option -M Bad modifier (%c). Use -Mf|r|t!\n", opt->arg[0]);
+					GMT_Report (API, GMT_MSG_ERROR, "Option -M Bad modifier (%c). Use -Mf|r|t!\n", opt->arg[0]);
 					n_errors++;
 				}
 				break;
@@ -157,12 +157,12 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct MGD77HEADER_CTRL *Ctrl, struct
 #define bailout(code) {gmt_M_free_options (mode); return (code);}
 #define Return(code) {Free_Ctrl (GMT, Ctrl); gmt_end_module (GMT, GMT_cpy); bailout (code);}
 
-int GMT_mgd77header (void *V_API, int mode, void *args) {
+EXTERN_MSC int GMT_mgd77header (void *V_API, int mode, void *args) {
 	int i, id, argno, length, id_col, t_col, x_col, y_col, saved_range, use;
 	int n_paths, counter[MGD77_MAX_COLS], quad_no, n_quad;
 	int b_col, twt_col, g_col, m_col, f_col, mt1_col, mt2_col;
 	int tendeg[36][18], tenx, teny, nten = 0, tquad;
-	
+
 	uint64_t rec;
 
 	bool error = false;
@@ -198,7 +198,7 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 
 	/* Parse the command-line arguments */
 
-	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
+	if ((GMT = gmt_init_module (API, THIS_MODULE_LIB, THIS_MODULE_CLASSIC_NAME, THIS_MODULE_KEYS, THIS_MODULE_NEEDS, NULL, &options, &GMT_cpy)) == NULL) bailout (API->error); /* Save current state */
 	if (GMT_Parse_Common (API, THIS_MODULE_OPTIONS, options)) Return (API->error);
 	Ctrl = New_Ctrl (GMT);	/* Allocate and initialize a new control structure */
 	MGD77_Init (GMT, &M);		/* Initialize input MGD77 Machinery */
@@ -211,7 +211,7 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 	tod = localtime (&tt);
 	if (Ctrl->H.active) {
 		if ((fp = gmt_fopen (GMT, Ctrl->H.file, "r")) == NULL) {
-			GMT_Report (API, GMT_MSG_NORMAL, "Cannot open header items input file (%s)\n", Ctrl->H.file);
+			GMT_Report (API, GMT_MSG_ERROR, "Cannot open header items input file (%s)\n", Ctrl->H.file);
 			Return (GMT_NO_INPUT);
 		}
 	}
@@ -223,7 +223,7 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 	n_paths = MGD77_Path_Expand (GMT, &M, options, &list);	/* Get list of requested IDs */
 
 	if (n_paths <= 0) {
-		GMT_Report (API, GMT_MSG_NORMAL, "No cruises given\n");
+		GMT_Report (API, GMT_MSG_ERROR, "No cruises given\n");
 		if (fp) gmt_fclose (GMT, fp);
 		Return (GMT_NO_INPUT);
 	}
@@ -238,12 +238,12 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 
 		if (MGD77_Open_File (GMT, list[argno], &M, MGD77_READ_MODE)) continue;
 
-		GMT_Report (API, GMT_MSG_LONG_VERBOSE, "Now processing cruise %s\n", list[argno]);
+		GMT_Report (API, GMT_MSG_INFORMATION, "Now processing cruise %s\n", list[argno]);
 
 		D = MGD77_Create_Dataset (GMT);
 
 		if (MGD77_Read_File_nohdr (GMT, list[argno], &M, D)) {
-			GMT_Report (API, GMT_MSG_NORMAL, "Error reading data for cruise %s\n", list[argno]);
+			GMT_Report (API, GMT_MSG_ERROR, "Failure while reading data for cruise %s\n", list[argno]);
 			Return (GMT_DATA_READ_ERROR);
 		}
 
@@ -376,7 +376,7 @@ int GMT_mgd77header (void *V_API, int mode, void *args) {
 	        if (xmax > 180) xmax -= 360.0;
 
 		if (gmt_M_is_dnan(tmin) || gmt_M_is_dnan(tmax)) {
-			GMT_Report (API, GMT_MSG_NORMAL, "Abort: cruise %s no time records\n", M.NGDC_id);
+			GMT_Report (API, GMT_MSG_ERROR, "Abort: cruise %s no time records\n", M.NGDC_id);
 			Return (GMT_DATA_READ_ERROR);
 		}
 		MGD77_Close_File (GMT, &M);
